import { create } from 'zustand'
import { persist } from 'zustand/middleware'

interface AuthState {
    clientOpenid:string,
    phone:string,
    code:string,
    tid:number,
    sign:string,
    activityCode:string,
    userId:string,
    corpId:string,
    timeStamp:string,
    redirect_url:string,
    tradeNo:string,
    setClientOpenId: (clientOpenid: string) => void,
    setCode: (code: string) => void,
    setPhone: (phone: string) => void,
    setTid: (tid: number) => void,
    setSign: (sign: string) => void,
    setActivityCode: (activityCode: string) => void,
    setUserId: (userId: string) => void,
    setCorpId: (corpId: string) => void,
    setTimeStamp: (timeStamp: string) => void,
    setRedirectUrl: (redirect_url: string) => void,
    setTradeNo: (tradeNo: string) => void,
    clear: () => void
}
export const useAuthStore = create<AuthState>()(
    persist(
        (set) => ({
            clientOpenid: '',
            code: '',
            tid: 0,
            phone: '',
            sign: '',
            activityCode: '',
            userId: '',
            corpId: '',
            timeStamp: '',
            redirect_url: '',
            tradeNo: '',
            setClientOpenId: (clientOpenid) => {
                set({ clientOpenid })
            },
            setCode: (code) => {
                set({ code })
            },
            setTid: (tid) => {
                set({ tid })
            },
            setPhone: (phone) => {
                set({ phone })
            },
            setSign: (sign) => {
                set({ sign})
            },
            setActivityCode: (activityCode) => {
                set({ activityCode })
            },
            setUserId: (userId) => {
                set({ userId })
            },
            setCorpId: (corpId) => {
                set({ corpId })
            },
            setTimeStamp: (timeStamp) => {
                set({ timeStamp })
            },
            setRedirectUrl: (redirect_url) => {
                set({ redirect_url })
            },
            setTradeNo: (tradeNo) => {
                set({ tradeNo })
            },
            clear: () => {
                set({ clientOpenid: '', code:'', 
                tid:0, phone:'', sign: '',redirect_url:'', 
                activityCode:'', userId:'', corpId:'', timeStamp:''})
            }   
        }),
        {
            name: 'authStore',
            getStorage: () => localStorage,
            partialize: (state) => ({
                tid: state.tid,
                clientOpenid: state.clientOpenid,
                code: state.code,
                phone: state.phone,
                sign: state.sign,
                activityCode: state.activityCode,
                userId: state.userId,
                corpId: state.corpId,
                timeStamp: state.timeStamp,
                redirect_url: state.redirect_url,
                tradeNo: state.tradeNo
            })
        }
    )
)